buildDictionary: Build a dictionary of missing-value recodes

View source: R/readstat_internal.R

buildDictionaryR Documentation

Build a dictionary of missing-value recodes

Description

Build a dataset-level dictionary of missing values and their recoded targets for internal SPSS-style normalization or export-oriented Stata/SAS mapping.

Usage

buildDictionary(dataset, to = c("SPSS", "Stata", "SAS"), start = -91)

Arguments

dataset

A data frame.

to

Target software for the recoding dictionary.

start

Starting code for generated SPSS-style numeric missings.

Value

A data frame with columns such as label, old, new, count, and n_variables.


DDIwR documentation built on Aug. 22, 2026, 9:07 a.m.

Related to buildDictionary in DDIwR...