recodeCharcat: Recode character categorical variables
Description
Recodes a character categorical variables to a numerical categorical
variable.
Usage
recodeCharcat(x, ...)
Value
A numeric categorical variable of the same class as the input.
Arguments
x
A character categorical variable
...
Other internal arguments
Author
Adrian Dusa
Details
For this function, a categorical variable is something else than a base
factor. It should be an object of class "declared" with a specific
attribute called "labels" that stores the value labels.