View source: R/readstat_internal.R
| buildDictionary | R Documentation |
Build a dataset-level dictionary of missing values and their recoded targets for internal SPSS-style normalization or export-oriented Stata/SAS mapping.
buildDictionary(dataset, to = c("SPSS", "Stata", "SAS"), start = -91)
dataset |
A data frame. |
to |
Target software for the recoding dictionary. |
start |
Starting code for generated SPSS-style numeric missings. |
A data frame with columns such as label, old, new, count,
and n_variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.