updateSchema: Updates the internal DDI Codebook schema object.

updateSchemaR Documentation

Updates the internal DDI Codebook schema object.

Description

Rebuilds the internal schema object, from a (newer) XML Schema codebook.xsd file.

Usage

updateSchema(xsd = NULL, return = FALSE)

Arguments

xsd

A path to the Codebook XML Schema file.

return

Return an R object representing the schema instead of updating the internal one.

Details

Releasing a new stable version of the DDI Codebook takes about 10 years. There are numerous elements and attributes that have to work together, and most importantly the Codebook has to obey the backward compatibility rule. Until a new version is released, the Codebook schema is incrementally modified by the DDI Alliance, in their GitHub repository.

This function is intended to update the internal DDI Codebook schema object, parsing the latest version of the Codebook XML Schema file.

Unless the codebook.xsd file is provided by the user, the function will attempt to read it from the DDI Alliance GitHub repository, located at: https://github.com/ddialliance/ddi-c_2

Author(s)

Adrian Dusa


DDIwR documentation built on Aug. 22, 2026, 9:07 a.m.

Related to updateSchema in DDIwR...