Rebuilds the internal schema object, from a (newer) XML Schema codebook.xsd file.
updateSchema(xsd = NULL, return = FALSE)A path to the Codebook XML Schema file.
Return an R object representing the schema instead of updating the internal one.
Adrian Dusa
Releasing a new stable version of the DDI Codebook takes about 10 years. There are numerous elements and attributes that have to work together, and most importantly the Codebook has to obey the backward compatibility rule. Until a new version is released, the Codebook schema is incrementally modified by the DDI Alliance, in their GitHub repository.
This function is intended to update the internal DDI Codebook schema object, parsing the latest version of the Codebook XML Schema file.
Unless the codebook.xsd file is provided by the user, the function will attempt to read it from the DDI Alliance GitHub repository, located at: https://github.com/ddialliance/ddi-c_2